/**
 * This module is responsible for handling metadata encoding and decoding in database records, which is
 * used for local timestamps (that lmdb-js can assign during a transaction for guaranteed monotonic
 * assignment across threads) and can be used for storing residency information as well. This
 * patches the primary store to properly get the metadata and assign it to the entries.
 */
import { Encoder } from 'msgpackr';
export declare const TIMESTAMP_PLACEHOLDER: Uint8Array;
export declare const LAST_TIMESTAMP_PLACEHOLDER: Uint8Array;
export declare const PREVIOUS_TIMESTAMP_PLACEHOLDER: Uint8Array;
export declare const LOCAL_TIMESTAMP: unique symbol;
export declare const METADATA: unique symbol;
export declare const NO_TIMESTAMP = 0;
export declare const TIMESTAMP_ASSIGN_NEW = 0;
export declare const TIMESTAMP_ASSIGN_LAST = 1;
export declare const TIMESTAMP_ASSIGN_PREVIOUS = 3;
export declare const TIMESTAMP_RECORD_PREVIOUS = 4;
export declare const HAS_EXPIRATION = 16;
export declare const PENDING_LOCAL_TIME = 1;
export declare class RecordEncoder extends Encoder {
    constructor(options: any);
    decode(buffer: any, options: any): any;
}
export declare function handleLocalTimeForGets(store: any): any;
export declare function getUpdateRecord(store: any, table_id: any, audit_store: any): (id: any, record: any, existing_entry: any, new_version: any, assign_metadata?: number, audit?: boolean, context?: any, expires_at?: number, type?: string, resolve_record?: boolean, audit_record?: any) => any;
